@@ -53,7 +53,7 @@ if __name__ == "__main__":
       "ui/help.png","ui/people.png",]
 
     print p
-    r = p.generate("0.5.3","1",changelog=" * Fix a bug on Autosync",tar=True,dsc=True,changes=True,build=False,src=True)
+    r = p.generate("0.5.5","1",changelog=" * Fix a bug on naive datetime",tar=True,dsc=True,changes=True,build=False,src=True)
     print r
 
-#scp *0.5.3-1* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
\ No newline at end of file
+#scp *0.5.4-1* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
\ No newline at end of file
