@@ -42,7 +42,7 @@ class mCalendar(object):
 
   __pretty_app_name__ = "mCalendar"
   __app_name__ = "mcalendar"
-  __version__ = "0.5.3"
+  __version__ = "0.5.5"
 
   _glade_files = [
 #    'ui/mcalendar.glade',
@@ -1127,7 +1127,7 @@ class mCalendar(object):
         self._eventeditor_edit_frequency.set_active(2)
       if frequency==0:
         self._eventeditor_edit_frequency.set_active(3)
-        
+
     #Attendee  and alarm Load
     self._eventeditor_load_attendees()
     self._eventeditor_load_alarm()
@@ -1276,15 +1276,23 @@ class mCalendar(object):
         if (uuid == 'new') or  (uuid==''):
           print model.get_value(selection_iter, 1)
           if (model.get_value(selection_iter, 1)!=self._prefs_get_allday_format()):
-            start_time = datetime.datetime.strptime(model.get_value(selection_iter, 1)[0:5],self._prefs_get_datetime_format())
-            end_time = datetime.datetime.strptime(model.get_value(selection_iter, 1)[8:13],self._prefs_get_datetime_format())
+            print model.get_value(selection_iter, 1)
+            if self._prefs_get_view_style() != 1:
+              start_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split('\n')[0],self._prefs_get_datetime_format())
+              end_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split('\n')[1],self._prefs_get_datetime_format())
+            else:
+              start_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split(' - ')[0],self._prefs_get_datetime_format())
+              end_time = datetime.datetime.strptime(model.get_value(selection_iter, 1).split(' - ')[1],self._prefs_get_datetime_format())
+            
           else:
             print 'debug 9'
             start_time = self.get_start_of_day()
             end_time = self.get_end_of_day()
-          start_datetime = datetime.datetime(self._current_datetime.year,self._current_datetime.month,self._current_datetime.day,start_time.hour,start_time.minute,0) 
-          end_datetime = datetime.datetime(self._current_datetime.year,self._current_datetime.month,self._current_datetime.day,end_time.hour,end_time.minute,0)
-          self._open_event(uuid,start_datetime,end_datetime)
+          start_datetime = datetime.datetime(self._current_datetime.year,self._current_datetime.month,self._current_datetime.day,start_time.hour,start_time.minute,0).replace(tzinfo=dateutil.tz.tzlocal()) 
+          end_datetime = datetime.datetime(self._current_datetime.year,self._current_datetime.month,self._current_datetime.day,end_time.hour,end_time.minute,0).replace(tzinfo=dateutil.tz.tzlocal())
+#          start_time = start_time
+#            end_time = end_time.replace(tzinfo=dateutil.tz.tzlocal())
+          self._open_event('',start_datetime,end_datetime)
         else:
           self._open_event(uuid)
 
